@@ -69,7 +69,7 @@ ShapesWidget::ShapesWidget(DWidget *parent)
     setMouseTracking(true);
     setAcceptDrops(true);
 
-    m_penColor = colorIndexOf(ConfigSettings::instance()->value(
+    m_penColor = BaseUtils::colorIndexOf(ConfigSettings::instance()->value(
                                   "common", "color_index").toInt());
 
     connect(m_menuController, &MenuController::shapePressed,
@@ -88,22 +88,31 @@ ShapesWidget::ShapesWidget(DWidget *parent)
             m_menuController, &MenuController::setUndoEnable);
     connect(ConfigSettings::instance(), &ConfigSettings::shapeConfigChanged,
             this, &ShapesWidget::updateSelectedShape);
-    m_sideBar = new SideBar(this);
-    m_sideBar->hide();
+    //m_sideBar = new SideBar(this);
+    //m_sideBar->hide();
 }
 
-ShapesWidget::~ShapesWidget() {}
-
+ShapesWidget::~ShapesWidget()
+{
+    if (m_menuController) {
+        delete m_menuController;
+        m_menuController = nullptr;
+    }
+}
+//更新选中的形状
 void ShapesWidget::updateSelectedShape(const QString &group,
                                        const QString &key, int index)
 {
-    qDebug() << "updateSelectedShapes" << m_selectedIndex << m_shapes.length() << m_selectedOrder;
-    if (m_isSlectedText) { //修复在截图区域，选中的文本框，字体会自动变颜色
-        m_isSlectedText = false;
+//    qDebug() << ">>>>> function: " << __func__ << ", line: " << __LINE__
+//             << ", group: " << group
+//             << ", key: " << key
+//             << ", index: " << index;
+    if (m_isSelectedText) { //修复在截图区域，选中的文本框，字体会自动变颜色
+        m_isSelectedText = false;
         return;
     }
     if ((group == m_currentShape.type || "common" == group) && key == "color_index") {
-        m_penColor = colorIndexOf(index);
+        m_penColor = BaseUtils::colorIndexOf(index);
     }
 
     if (m_selectedIndex != -1 && m_selectedOrder != -1 && m_selectedOrder < m_shapes.length()) {
@@ -118,7 +127,7 @@ void ShapesWidget::updateSelectedShape(const QString &group,
         } else if (group == "text" && m_selectedShape.type == group && key == "color_index") {
             int tmpIndex = m_shapes[m_selectedOrder].index;
             if (m_editMap.contains(tmpIndex)) {
-                m_editMap.value(tmpIndex)->setColor(colorIndexOf(index));
+                m_editMap.value(tmpIndex)->setColor(BaseUtils::colorIndexOf(index));
                 m_editMap.value(tmpIndex)->update();
             }
 
@@ -138,6 +147,8 @@ void ShapesWidget::updateSelectedShape(const QString &group,
         }
         update();
     }
+    qDebug() << ">>>>> function: " << __func__ << ", line: " << __LINE__ <<
+             ", m_selectedShape.type: " << m_selectedShape.type;
 }
 /*
  * never used
@@ -174,7 +185,7 @@ void ShapesWidget::clearSelected()
         m_hoveredShape.mainPoints[j] = QPointF(0, 0);
     }
 
-    qDebug() << "clear selected!!!";
+    //qDebug() << "clear selected!!!";
     m_isSelected = false;
     m_selectedShape.points.clear();
     m_hoveredShape.points.clear();
@@ -201,14 +212,11 @@ void ShapesWidget::setAllTextEditReadOnly()
 
 void ShapesWidget::setNoChangedTextEditRemove()
 {
-    qDebug() << "delete text";
     if (m_shapes.length() == 0) {
         return;
     }
     for (int i = 0; i < m_shapes.length(); i++) {
-        qDebug() << "delete text11111111111";
         if (m_shapes[i].type == "text") {
-            qDebug() << "delete text22222222222222";
             int t_tempIndex = m_shapes[i].index;
             if (m_editMap.value(t_tempIndex)->document()->toPlainText() == QString(tr("Input text here"))
                     || m_editMap.value(t_tempIndex)->document()->toPlainText().isEmpty()) {
@@ -237,14 +245,16 @@ void ShapesWidget::saveActionTriggered()
     m_clearAllTextBorder = true;
 }
 
+//点击某个形状
 bool ShapesWidget::clickedOnShapes(QPointF pos)
 {
     bool onShapes = false;
     m_selectedOrder = -1;
-
-
-    qDebug() << "ClickedOnShapes !!!!!!!" << m_shapes.length();
+//    qDebug() << ">>>>> function: " << __func__ << ", line: " << __LINE__
+//             << ", pos: " << pos
+//             << ", m_shapes.length(): " << m_shapes.length();
     for (int i = 0; i < m_shapes.length(); i++) {
+        //当前是否有形状被选中
         bool currentOnShape = false;
         if (m_shapes[i].type == "rectangle") {
             if (clickedOnRect(m_shapes[i].mainPoints, pos,
@@ -293,7 +303,6 @@ bool ShapesWidget::clickedOnShapes(QPointF pos)
             m_selectedIndex = m_shapes[i].index;
             m_selectedOrder = i;
             onShapes = true;
-            qDebug() << "currentOnShape" << i << m_selectedIndex;
             break;
         } else {
             m_selectedIndex = -1;
@@ -305,6 +314,7 @@ bool ShapesWidget::clickedOnShapes(QPointF pos)
     return onShapes;
 }
 
+//判断是否选中图形,不是真实鼠标事件会触发
 bool ShapesWidget::clickedShapes(QPointF pos)
 {
     for (int i = 0; i < m_shapes.length(); i++) {
@@ -341,6 +351,7 @@ bool ShapesWidget::clickedShapes(QPointF pos)
 }
 
 //TODO: selectUnique
+//矩形是否被点击
 bool ShapesWidget::clickedOnRect(FourPoints rectPoints, QPointF pos, bool isBlurMosaic)
 {
     m_isSelected = false;
@@ -381,7 +392,7 @@ bool ShapesWidget::clickedOnRect(FourPoints rectPoints, QPointF pos, bool isBlur
         m_resizeDirection = BottomRight;
         m_pressedPoint = pos;
         return true;
-    }  else if (pointClickIn(otherFPoints[0], pos)) {
+    } else if (pointClickIn(otherFPoints[0], pos)) {
         m_isSelected = true;
         m_isResize = true;
         m_clickedKey = Fifth;
@@ -416,8 +427,9 @@ bool ShapesWidget::clickedOnRect(FourPoints rectPoints, QPointF pos, bool isBlur
         m_resizeDirection = Rotate;
         m_pressedPoint = pos;
         return true;
-    } else if (pointOnLine(rectPoints[0], rectPoints[1], pos) || pointOnLine(rectPoints[1],
-                                                                             rectPoints[3], pos) || pointOnLine(rectPoints[3], rectPoints[2], pos) ||
+    } else if (pointOnLine(rectPoints[0], rectPoints[1], pos) ||
+               pointOnLine(rectPoints[1], rectPoints[3], pos) ||
+               pointOnLine(rectPoints[3], rectPoints[2], pos) ||
                pointOnLine(rectPoints[2], rectPoints[0], pos)) {
         m_isSelected = true;
         m_isResize = false;
@@ -439,6 +451,7 @@ bool ShapesWidget::clickedOnRect(FourPoints rectPoints, QPointF pos, bool isBlur
     return false;
 }
 
+//圆形是否被点击
 bool ShapesWidget::clickedOnEllipse(FourPoints mainPoints, QPointF pos, bool isBlurMosaic)
 {
     m_isSelected = false;
@@ -532,6 +545,7 @@ bool ShapesWidget::clickedOnEllipse(FourPoints mainPoints, QPointF pos, bool isB
     return false;
 }
 
+//箭头是否被点击
 bool ShapesWidget::clickedOnArrow(QList<QPointF> points, QPointF pos)
 {
     if (points.length() != 2)
@@ -592,8 +606,10 @@ bool ShapesWidget::clickedOnArrow(QList<QPointF> points, QPointF pos)
 
 }
 
+//画出的线是否被点击
 bool ShapesWidget::clickedOnLine(FourPoints mainPoints,
-                                 QList<QPointF> points, QPointF pos)
+                                 QList<QPointF> points,
+                                 QPointF pos)
 {
     m_isSelected = false;
     m_isResize = false;
@@ -680,6 +696,7 @@ bool ShapesWidget::clickedOnLine(FourPoints mainPoints,
     return false;
 }
 
+//文本框是否被点击
 bool ShapesWidget::clickedOnText(FourPoints mainPoints, QPointF pos)
 {
     if (pointInRect(mainPoints, pos)) {
@@ -801,13 +818,13 @@ bool ShapesWidget::hoverOnArrow(QList<QPointF> points, QPointF pos)
     if (pointOnLine(points[0], points[1], pos)) {
         m_resizeDirection = Moving;
         return true;
-    } else if ( m_selectedIndex != -1 && m_selectedIndex == m_hoveredIndex
-                && pointClickIn(points[0], pos)) {
+    } else if (m_selectedIndex != -1 && m_selectedIndex == m_hoveredIndex
+               && pointClickIn(points[0], pos)) {
         m_clickedKey = First;
         m_resizeDirection = Rotate;
         return true;
-    } else if ( m_selectedIndex != -1 && m_selectedIndex == m_hoveredIndex
-                && pointClickIn(points[1], pos)) {
+    } else if (m_selectedIndex != -1 && m_selectedIndex == m_hoveredIndex
+               && pointClickIn(points[1], pos)) {
         m_clickedKey =   Second;
         m_resizeDirection = Rotate;
         return true;
@@ -873,9 +890,11 @@ bool ShapesWidget::hoverOnText(FourPoints mainPoints, QPointF pos)
 {
 //    qDebug() << "hoverOnText:" <<  mainPoints << pos;
 
-    if (hoverOnRect(mainPoints, pos, true) ||  (pos.x() >= mainPoints[0].x() - 5
-                                                && pos.x() <= mainPoints[2].x() + 5 && pos.y() >= mainPoints[0].y() - 5
-                                                && pos.y() <= mainPoints[2].y() + 5)) {
+    if (hoverOnRect(mainPoints, pos, true) ||
+            (pos.x() >= mainPoints[0].x() - 5
+             && pos.x() <= mainPoints[2].x() + 5
+             && pos.y() >= mainPoints[0].y() - 5
+             && pos.y() <= mainPoints[2].y() + 5)) {
 //        qDebug() << "hoverOnText Moving";
         m_resizeDirection = Moving;
         return true;
@@ -949,7 +968,7 @@ bool ShapesWidget::textEditIsReadOnly()
 
 void ShapesWidget::handleDrag(QPointF oldPoint, QPointF newPoint)
 {
-    qDebug() << "handleDrag:" << m_selectedIndex << m_shapes.length();
+    //qDebug() << "handleDrag:" << m_selectedIndex << m_shapes.length();
 
     if (m_selectedIndex == -1) {
         return;
@@ -1049,28 +1068,26 @@ void ShapesWidget::handleRotate(QPointF pos)
                                      m_selectedShape.mainPoints[3].x()) / 2,
                                     (m_selectedShape.mainPoints[0].y() +
                                      m_selectedShape.mainPoints[3].y()) / 2);
-    QLineF linePressed(centerInPoint,m_movingPoint);
+    QLineF linePressed(centerInPoint, m_movingPoint);
     qreal pressedAngle = 360 - linePressed.angle();
     qreal angle;
-    if(0 == static_cast<int>(m_lastAngle)){
+    if (0 == static_cast<int>(m_lastAngle)) {
         m_lastAngle = pressedAngle;
         angle = 0;
-    }
-    else {
+    } else {
         angle = pressedAngle - m_lastAngle;
     }
-    if(angle < -100){
+    if (angle < -100) {
         m_lastAngle = pressedAngle - m_lastAngle + 360;
         angle = m_lastAngle;
-    }
-    else if(angle > 100){
+    } else if (angle > 100) {
         m_lastAngle = pressedAngle - m_lastAngle - 360;
         angle = m_lastAngle;
     }
-    qreal rotationDelta = (angle*M_PI)/180;
+    qreal rotationDelta = (angle * M_PI) / 180;
     qreal centerX = (m_shapes[m_selectedOrder].mainPoints[0].x() + m_shapes[m_selectedOrder].mainPoints[3].x()) / 2;
     qreal centerY = (m_shapes[m_selectedOrder].mainPoints[0].y() + m_shapes[m_selectedOrder].mainPoints[3].y()) / 2;
-    for(int i = 0; i < m_shapes[m_selectedOrder].mainPoints.size(); ++i){
+    for (int i = 0; i < m_shapes[m_selectedOrder].mainPoints.size(); ++i) {
         qreal x = centerX + (m_shapes[m_selectedOrder].mainPoints[i].x() - centerX) * cos(rotationDelta) - (m_shapes[m_selectedOrder].mainPoints[i].y() - centerY) * sin(rotationDelta);
         qreal y = centerY + (m_shapes[m_selectedOrder].mainPoints[i].x() - centerX) * sin(rotationDelta) + (m_shapes[m_selectedOrder].mainPoints[i].y() - centerY) * cos(rotationDelta);
         //图形
@@ -1131,11 +1148,11 @@ void ShapesWidget::handleResize(QPointF pos, int key)
 
 bool ShapesWidget::event(QEvent *event)
 {
-    if (QEvent::Gesture == event->type()){
-        if (QGesture *tap = static_cast<QGestureEvent *>(event)->gesture(Qt::TapGesture)){
+    if (QEvent::Gesture == event->type()) {
+        if (QGesture *tap = static_cast<QGestureEvent *>(event)->gesture(Qt::TapGesture)) {
             tapTriggered(static_cast<QTapGesture *>(tap));
         }
-        if (QGesture *pinch = static_cast<QGestureEvent *>(event)->gesture(Qt::PinchGesture)){
+        if (QGesture *pinch = static_cast<QGestureEvent *>(event)->gesture(Qt::PinchGesture)) {
             pinchTriggered(static_cast<QPinchGesture *>(pinch));
         }
 //        if (QGesture *pan = static_cast<QGestureEvent *>(event)->gesture(Qt::PanGesture)){
@@ -1155,11 +1172,35 @@ bool ShapesWidget::event(QEvent *event)
     return QWidget::event(event);
 }
 
+//重写鼠标按压事件
 void ShapesWidget::mousePressEvent(QMouseEvent *e)
 {
     m_lastAngle = 0;
-    if(Qt::MouseEventSource::MouseEventSynthesizedByQt != e->source()
-            && m_selectedIndex != -1){
+    //选中图形后，重新按下真实鼠标左键
+    if (Qt::MouseEventSource::MouseEventSynthesizedByQt != e->source()
+            && m_selectedIndex != -1) {
+        // 判空
+        if(nullptr != m_editMap.value(m_lastEditMapKey)){
+            // 点击鼠标左键时，去掉未更改的textEdit文本框
+            if (m_editMap.value(m_lastEditMapKey)->toPlainText() == QString(tr("Input text here")) ||
+                    m_editMap.value(m_lastEditMapKey)->toPlainText().isEmpty()) {
+                clearSelected();
+                setAllTextEditReadOnly();
+                m_editing = false;
+                m_selectedIndex = -1;
+                m_selectedOrder = -1;
+                m_selectedShape.type = "";
+                update();
+                DFrame::mousePressEvent(e);
+            }
+        }
+    }
+
+    //选中图形后，重新按下触摸屏左键
+    if (Qt::MouseEventSource::MouseEventSynthesizedByQt == e->source()
+            && m_selectedIndex != -1
+            && !clickedShapes(e->pos())
+            && "text" != m_currentType) {
         clearSelected();
         setAllTextEditReadOnly();
         m_editing = false;
@@ -1168,13 +1209,10 @@ void ShapesWidget::mousePressEvent(QMouseEvent *e)
         m_selectedShape.type = "";
         update();
         DFrame::mousePressEvent(e);
-    }
 
-    if(Qt::MouseEventSource::MouseEventSynthesizedByQt == e->source()
-            && m_selectedIndex != -1
-            && !clickedShapes(e->pos())
-            && "text" != m_currentType)
-        return;
+        //return;
+
+    }
 
     if (m_selectedIndex != -1) {
         if (!(clickedOnShapes(e->pos()) && m_isRotated) && m_selectedIndex == -1 && "text" == m_currentType) {
@@ -1190,7 +1228,9 @@ void ShapesWidget::mousePressEvent(QMouseEvent *e)
         }
     }
 
+    //鼠标右键点击
     if (Qt::MouseEventSource::MouseEventSynthesizedByQt != e->source() && e->button() == Qt::RightButton) {
+        m_pos1 = QPointF(0,0); // 修复触控屏绘制矩形后，长按屏幕会出现多余矩形的问题
         qDebug() << "RightButton clicked!" << e->source();
         m_menuController->showMenu(QPoint(mapToGlobal(e->pos())));
         DFrame::mousePressEvent(e);
@@ -1199,11 +1239,10 @@ void ShapesWidget::mousePressEvent(QMouseEvent *e)
 
     m_pressedPoint = e->pos();
     m_isPressed = true;
-    qDebug() << "mouse pressed!" << m_pressedPoint;
-
     if (!clickedOnShapes(m_pressedPoint)) {
+
         m_isRecording = true;
-        qDebug() << "no one shape be clicked!" << m_selectedIndex << m_shapes.length();
+        //qDebug() << "no one shape be clicked!" << m_selectedIndex << m_shapes.length();
 
         m_currentShape.type = m_currentType;
         m_currentShape.colorIndex = ConfigSettings::instance()->value(
@@ -1272,6 +1311,7 @@ void ShapesWidget::mousePressEvent(QMouseEvent *e)
                     QString t_editText = QString(tr("Input text here"));
                     edit->setPlainText(t_editText);
                     m_editing = true;
+                    edit->setEditing(true);
                     int defaultFontSize = ConfigSettings::instance()->value("text", "fontsize").toInt();
                     m_currentShape.fontSize = defaultFontSize;
 
@@ -1284,7 +1324,7 @@ void ShapesWidget::mousePressEvent(QMouseEvent *e)
                     m_editMap.insert(m_currentIndex, edit);
                     m_selectedIndex = m_currentIndex;
                     m_selectedShape = m_currentShape;
-
+                    m_lastEditMapKey = m_currentIndex;
 //                    m_selectedOrder = m_currentIndex;
 //                    updateTextRect();
 
@@ -1294,7 +1334,7 @@ void ShapesWidget::mousePressEvent(QMouseEvent *e)
 //                    connect(edit, &TextEdit::backToEditing, this, [ = ] {
 //                        m_editing = true;
 //                    });
-                    connect(edit, &TextEdit::clickToEditing, this, [ = ] (int index) {
+                    connect(edit, &TextEdit::clickToEditing, this, [ = ](int index) {
 //                        setAllTextEditReadOnly();
                         for (int k = 0; k < m_shapes.length(); k++) {
                             if (m_shapes[k].type == "text" && m_shapes[k].index == index) {
@@ -1319,7 +1359,7 @@ void ShapesWidget::mousePressEvent(QMouseEvent *e)
                             ++i;
                         }
                         m_editing = true;
-                        m_isSlectedText = false;
+                        m_isSelectedText = false;
                         emit shapeClicked("text");
 
                     });
@@ -1353,11 +1393,11 @@ void ShapesWidget::mousePressEvent(QMouseEvent *e)
                             i.value()->setTextCursor(textCursor);
                             ++i;
                         }
-                        m_isSlectedText = true;
+                        m_isSelectedText = true;
                         emit shapeClicked("text");
                     });
 
-                    connect(edit, &TextEdit::textEditFinish, this, [ = ] (int index) {
+                    connect(edit, &TextEdit::textEditFinish, this, [ = ](int index) {
 //                        setAllTextEditReadOnly();
                         Q_UNUSED(index);
                         setAllTextEditReadOnly();
@@ -1371,7 +1411,7 @@ void ShapesWidget::mousePressEvent(QMouseEvent *e)
                     edit->moveCursor(QTextCursor::Start);
                     cs.movePosition(QTextCursor::Right, QTextCursor::KeepAnchor, t_editText.length());
                     edit->setTextCursor(cs);
-
+                    edit->selectAll();
                     m_shapes.append(m_currentShape);
 
 
@@ -1393,7 +1433,7 @@ void ShapesWidget::mousePressEvent(QMouseEvent *e)
         }
     } else {
         m_isRecording = false;
-        qDebug() << "some on shape be clicked!";
+        //qDebug() << "some on shape be clicked!";
         if (m_editing && m_editMap.contains(m_shapes[m_selectedOrder].index)) {
             m_editMap.value(m_shapes[m_selectedOrder].index)->setReadOnly(true);
             m_editMap.value(m_shapes[m_selectedOrder].index)->setCursorVisible(false);
@@ -1402,6 +1442,7 @@ void ShapesWidget::mousePressEvent(QMouseEvent *e)
         update();
     }
     DFrame::mousePressEvent(e);
+
 }
 
 void ShapesWidget::mouseReleaseEvent(QMouseEvent *e)
@@ -1409,9 +1450,9 @@ void ShapesWidget::mouseReleaseEvent(QMouseEvent *e)
     m_isPressed = false;
     m_isMoving = false;
 
-    if(Qt::MouseEventSource::MouseEventSynthesizedByQt == e->source()
+    if (Qt::MouseEventSource::MouseEventSynthesizedByQt == e->source()
             && -1 != m_selectedIndex
-            && "text" != m_currentType){
+            && "text" != m_currentType) {
         return;
     }
 
@@ -1426,8 +1467,8 @@ void ShapesWidget::mouseReleaseEvent(QMouseEvent *e)
         DFrame::mousePressEvent(e);
     }
 
-    qDebug() << m_isRecording << m_isSelected << m_pos2;
-    if (m_isRecording && !m_isSelected && m_pos2 != QPointF(0, 0) ) {
+    //qDebug() << m_isRecording << m_isSelected << m_pos2;
+    if (m_isRecording && !m_isSelected && m_pos2 != QPointF(0, 0)) {
         if (m_currentType == "arrow") {
             if (m_currentShape.points.length() == 2) {
                 if (m_isShiftPressed) {
@@ -1454,7 +1495,7 @@ void ShapesWidget::mouseReleaseEvent(QMouseEvent *e)
             m_shapes.append(m_currentShape);
         }
 
-        qDebug() << "ShapesWidget num:" << m_shapes.length();
+        //qDebug() << "ShapesWidget num:" << m_shapes.length();
         clearSelected();
     }
 
@@ -1538,7 +1579,7 @@ void ShapesWidget::mouseMoveEvent(QMouseEvent *e)
 
         if (m_isSelected && m_isPressed && m_selectedIndex != -1) {
             handleDrag(m_pressedPoint, m_movingPoint);
-            qDebug() << "move m_selectedOrder:" << m_selectedOrder;
+            //qDebug() << "move m_selectedOrder:" << m_selectedOrder;
             m_selectedShape = m_shapes[m_selectedOrder];
             m_hoveredShape = m_shapes[m_selectedOrder];
 
@@ -1611,7 +1652,7 @@ void ShapesWidget::mouseMoveEvent(QMouseEvent *e)
                             qApp->setOverrideCursor(Qt::ClosedHandCursor);
                         }
                     } else if (m_resizeDirection == Rotate) {
-                        qApp->setOverrideCursor(setCursorShape("rotate"));
+                        qApp->setOverrideCursor(BaseUtils::setCursorShape("rotate"));
                     } else if (m_resizeDirection == Moving) {
                         qApp->setOverrideCursor(Qt::ClosedHandCursor);
                     } else {
@@ -1779,7 +1820,7 @@ void ShapesWidget::paintArrow(QPainter &painter, QList<QPointF> lineFPoints,
                 path.lineTo(arrowPoints[1].x(), arrowPoints[1].y());
                 path.lineTo(arrowPoints[2].x(), arrowPoints[2].y());
             }
-            painter.setPen (Qt :: NoPen);
+            painter.setPen(Qt :: NoPen);
             painter.fillPath(path, QBrush(oldPen.color()));
         } else {
             painter.drawLine(lineFPoints[0], lineFPoints[1]);
@@ -1822,16 +1863,18 @@ void ShapesWidget::paintEvent(QPaintEvent *)
     painter.setRenderHints(QPainter::Antialiasing);
     QPen pen;
     for (int i = 0; i < m_shapes.length(); i++) {
-        pen.setColor(colorIndexOf(m_shapes[i].colorIndex));
+        pen.setColor(BaseUtils::colorIndexOf(m_shapes[i].colorIndex));
         pen.setWidthF(m_shapes[i].lineWidth - 0.5);
 
         if (m_shapes[i].type == "rectangle") {
             pen.setJoinStyle(Qt::MiterJoin);
             painter.setPen(pen);
             if ((m_shapes[i].isBlur || m_shapes[i].isMosaic) && m_selectedOrder == i) {
+                //画出具有模糊和马赛克效果的矩形框
                 paintRect(painter, m_shapes[i].mainPoints, i, Drawing,
                           m_shapes[i].isBlur, m_shapes[i].isMosaic);
             } else {
+                //画出普通的矩形框
                 paintRect(painter, m_shapes[i].mainPoints, m_shapes.length(), Normal,
                           m_shapes[i].isBlur, m_shapes[i].isMosaic);
             }
@@ -1863,20 +1906,21 @@ void ShapesWidget::paintEvent(QPaintEvent *)
                     }
                     break;
                 }
-                m++;
+                ++m;
             }
         }
     }
 
     if ((m_pos1 != QPointF(0, 0) && m_pos2 != QPointF(0, 0)) || m_currentShape.type == "text") {
         FourPoints currentFPoint =  getMainPoints(m_pos1, m_pos2, m_isShiftPressed);
-        pen.setColor(colorIndexOf(m_currentShape.colorIndex));
+        pen.setColor(BaseUtils::colorIndexOf(m_currentShape.colorIndex));
         pen.setWidthF(m_currentShape.lineWidth - 0.5);
 
-        if (m_currentType == "rectangle") {
-            if (m_currentShape.type == "text") {
-                return;
-            }
+//        qDebug() << ">>>>> function: " << __func__ << ", line: " << __LINE__
+//                 << ", m_currentShape.type: " << m_currentShape.type
+//                 << ", m_currentType: " << m_currentType;
+
+        if (m_currentType == "rectangle" && m_currentShape.type != "text") {
             pen.setJoinStyle(Qt::MiterJoin);
             painter.setPen(pen);
             if (m_currentShape.isBlur || m_currentShape.isMosaic) {
@@ -1886,10 +1930,7 @@ void ShapesWidget::paintEvent(QPaintEvent *)
                 paintRect(painter, currentFPoint, m_shapes.length(), Normal,
                           m_currentShape.isBlur, m_currentShape.isMosaic);
             }
-        } else if (m_currentType == "oval") {
-            if (m_currentShape.type == "text") {
-                return;
-            }
+        } else if (m_currentType == "oval" && m_currentShape.type != "text") {
             pen.setJoinStyle(Qt::MiterJoin);
             painter.setPen(pen);
             if (m_currentShape.isBlur || m_currentShape.isMosaic) {
@@ -1899,17 +1940,11 @@ void ShapesWidget::paintEvent(QPaintEvent *)
                 paintEllipse(painter, currentFPoint, m_shapes.length(), Normal,
                              m_currentShape.isBlur, m_currentShape.isMosaic);
             }
-        } else if (m_currentType == "arrow") {
-            if (m_currentShape.type == "text") {
-                return;
-            }
+        } else if (m_currentType == "arrow" && m_currentShape.type != "text") {
             pen.setJoinStyle(Qt::MiterJoin);
             painter.setPen(pen);
             paintArrow(painter, m_currentShape.points, pen.width(), m_currentShape.isStraight);
-        } else if (m_currentType == "line") {
-            if (m_currentShape.type == "text") {
-                return;
-            }
+        } else if (m_currentType == "line" && m_currentShape.type != "text") {
             pen.setJoinStyle(Qt::RoundJoin);
             painter.setPen(pen);
             paintLine(painter, m_currentShape.points);
@@ -1954,6 +1989,7 @@ void ShapesWidget::paintEvent(QPaintEvent *)
                                                RESIZEPOINT_WIDTH));
     resizePointImg.setDevicePixelRatio(ration);
 
+    //只有当选中图形时m_selectedShape才会有内容
     if (m_selectedShape.type == "arrow" && m_selectedShape.points.length() == 2) {
 
 //        qreal t_minx = qMin(m_selectedShape.points[1].x(), m_selectedShape.points[0].x());
@@ -1974,11 +2010,12 @@ void ShapesWidget::paintEvent(QPaintEvent *)
 //        rotatePointImg.setDevicePixelRatio(this->devicePixelRatioF());
 //        paintImgPointArrow(painter, t_midpos, rotatePointImg);
 
-    } else if (m_selectedShape.type != "text") {
+    } else if (m_selectedShape.type != "" && m_selectedShape.type != "text") {
         if (m_selectedShape.mainPoints[0] != QPointF(0, 0) || m_selectedShape.type == "arrow") {
 
             QPointF rotatePoint = getRotatePoint(m_selectedShape.mainPoints[0],
-                                                 m_selectedShape.mainPoints[1], m_selectedShape.mainPoints[2],
+                                                 m_selectedShape.mainPoints[1],
+                                                 m_selectedShape.mainPoints[2],
                                                  m_selectedShape.mainPoints[3]);
 
             if (m_selectedShape.type == "oval" || m_selectedShape.type == "line") {
@@ -1995,11 +2032,13 @@ void ShapesWidget::paintEvent(QPaintEvent *)
             rotatePointImg.setDevicePixelRatio(this->devicePixelRatioF());
             paintImgPoint(painter, rotatePoint, rotatePointImg, false);
 
-            for ( int i = 0; i < m_selectedShape.mainPoints.length(); i ++) {
+            //画出形状的主要骨架点
+            for (int i = 0; i < m_selectedShape.mainPoints.length(); i ++) {
 
                 paintImgPoint(painter, m_selectedShape.mainPoints[i], resizePointImg);
             }
 
+            //画出形状的其他骨架点
             FourPoints anotherFPoints = getAnotherFPoints(m_selectedShape.mainPoints);
             for (int j = 0; j < anotherFPoints.length(); j++) {
                 paintImgPoint(painter, anotherFPoints[j], resizePointImg);
@@ -2015,24 +2054,23 @@ void ShapesWidget::enterEvent(QEvent *e)
 {
     Q_UNUSED(e);
     if (m_currentType != "line") {
-        qApp->setOverrideCursor(setCursorShape(m_currentType));
+        qApp->setOverrideCursor(BaseUtils::setCursorShape(m_currentType));
     } else {
         int colIndex = ConfigSettings::instance()->value(m_currentType, "color_index").toInt();
-        qDebug() << "enterEvent:" << colIndex << colorIndex(m_penColor);
-        qApp->setOverrideCursor(setCursorShape("line",  colIndex));
+        qApp->setOverrideCursor(BaseUtils::setCursorShape("line",  colIndex));
     }
 }
 
 void ShapesWidget::pinchTriggered(QPinchGesture *pinch)
 {
-    if(-1 == m_selectedIndex || "text" == m_currentType)
+    if (-1 == m_selectedIndex || "text" == m_currentType)
         return;
     QPinchGesture::ChangeFlags changeFlags = pinch->changeFlags();
     if (changeFlags & QPinchGesture::RotationAngleChanged) {
-        qreal rotationDelta = (pinch->rotationAngle() - pinch->lastRotationAngle())*0.01;
+        qreal rotationDelta = (pinch->rotationAngle() - pinch->lastRotationAngle()) * 0.01;
         qreal centerX = (m_shapes[m_selectedOrder].mainPoints[0].x() + m_shapes[m_selectedOrder].mainPoints[3].x()) / 2;
         qreal centerY = (m_shapes[m_selectedOrder].mainPoints[0].y() + m_shapes[m_selectedOrder].mainPoints[3].y()) / 2;
-        for(int i = 0; i < m_shapes[m_selectedOrder].mainPoints.size(); ++i){
+        for (int i = 0; i < m_shapes[m_selectedOrder].mainPoints.size(); ++i) {
             qreal x = centerX + (m_shapes[m_selectedOrder].mainPoints[i].x() - centerX) * cos(rotationDelta) - (m_shapes[m_selectedOrder].mainPoints[i].y() - centerY) * sin(rotationDelta);
             qreal y = centerY + (m_shapes[m_selectedOrder].mainPoints[i].x() - centerX) * sin(rotationDelta) + (m_shapes[m_selectedOrder].mainPoints[i].y() - centerY) * cos(rotationDelta);
             //图形
@@ -2041,7 +2079,7 @@ void ShapesWidget::pinchTriggered(QPinchGesture *pinch)
         }
         qreal centerMainX = (m_selectedShape.mainPoints[0].x() + m_selectedShape.mainPoints[3].x()) / 2;
         qreal centerMainY = (m_selectedShape.mainPoints[0].y() + m_selectedShape.mainPoints[3].y()) / 2;
-        for ( int i = 0; i < m_selectedShape.mainPoints.length(); i ++) {
+        for (int i = 0; i < m_selectedShape.mainPoints.length(); i ++) {
             qreal x = centerMainX + (m_selectedShape.mainPoints[i].x() - centerMainX) * cos(rotationDelta) - (m_selectedShape.mainPoints[i].y() - centerMainY) * sin(rotationDelta);
             qreal y = centerMainY + (m_selectedShape.mainPoints[i].x() - centerMainX) * sin(rotationDelta) + (m_selectedShape.mainPoints[i].y() - centerMainY) * cos(rotationDelta);
             //选中状态，点+线条
@@ -2061,7 +2099,7 @@ void ShapesWidget::pinchTriggered(QPinchGesture *pinch)
         qreal ascanle = (scale - 1) * 0.3 + 1;
         qreal centerX = (m_shapes[m_selectedOrder].mainPoints[0].x() + m_shapes[m_selectedOrder].mainPoints[3].x()) / 2;
         qreal centerY = (m_shapes[m_selectedOrder].mainPoints[0].y() + m_shapes[m_selectedOrder].mainPoints[3].y()) / 2;
-        for(int i = 0; i < m_shapes[m_selectedOrder].mainPoints.size(); ++i){
+        for (int i = 0; i < m_shapes[m_selectedOrder].mainPoints.size(); ++i) {
             qreal x = m_shapes[m_selectedOrder].mainPoints[i].x() * ascanle + centerX * (1 - ascanle);
             qreal y = m_shapes[m_selectedOrder].mainPoints[i].y() * ascanle + centerY * (1 - ascanle);
             m_shapes[m_selectedOrder].mainPoints[i].setX(x);
@@ -2069,7 +2107,7 @@ void ShapesWidget::pinchTriggered(QPinchGesture *pinch)
         }
         qreal centerMainX = (m_selectedShape.mainPoints[0].x() + m_selectedShape.mainPoints[3].x()) / 2;
         qreal centerMainY = (m_selectedShape.mainPoints[0].y() + m_selectedShape.mainPoints[3].y()) / 2;
-        for ( int i = 0; i < m_selectedShape.mainPoints.length(); i ++) {
+        for (int i = 0; i < m_selectedShape.mainPoints.length(); i ++) {
             qreal x = m_selectedShape.mainPoints[i].x() * ascanle + centerMainX * (1 - ascanle);
             qreal y = m_selectedShape.mainPoints[i].y() * ascanle + centerMainY * (1 - ascanle);
             m_selectedShape.mainPoints[i].setX(x);
@@ -2086,7 +2124,7 @@ void ShapesWidget::pinchTriggered(QPinchGesture *pinch)
 
 void ShapesWidget::tapTriggered(QTapGesture *tap)
 {
-    if(tap->state() == Qt::GestureState::GestureFinished && !clickedOnShapes(m_movingPoint) && -1 != m_selectedIndex && "text" != m_currentType){
+    if (tap->state() == Qt::GestureState::GestureFinished && !clickedOnShapes(m_movingPoint) && -1 != m_selectedIndex && "text" != m_currentType) {
         m_isPressed = false;
         m_isMoving = false;
         clearSelected();
@@ -2136,7 +2174,7 @@ void ShapesWidget::undoDrawShapes()
         deleteCurrentShape();
     } else if (m_shapes.length() > 0) {
         int tmpIndex = m_shapes[m_shapes.length() - 1].index;
-        if (m_shapes[m_shapes.length() - 1].type == "text" && m_editMap.contains(tmpIndex) ) {
+        if (m_shapes[m_shapes.length() - 1].type == "text" && m_editMap.contains(tmpIndex)) {
             m_editMap.value(tmpIndex)->clear();
             delete m_editMap.value(tmpIndex);
             m_editMap.remove(tmpIndex);
@@ -2161,7 +2199,7 @@ void ShapesWidget::undoAllDrawShapes()
     } else if (m_shapes.length() > 0) {
         while (m_shapes.length() > 0) {
             int tmpIndex = m_shapes[m_shapes.length() - 1].index;
-            if (m_shapes[m_shapes.length() - 1].type == "text" && m_editMap.contains(tmpIndex) ) {
+            if (m_shapes[m_shapes.length() - 1].type == "text" && m_editMap.contains(tmpIndex)) {
                 m_editMap.value(tmpIndex)->clear();
                 delete m_editMap.value(tmpIndex);
                 m_editMap.remove(tmpIndex);
@@ -2229,12 +2267,17 @@ void ShapesWidget::setShiftKeyPressed(bool isShift)
 
 void ShapesWidget::updateCursorShape()
 {
+    QCursor setCursorValue;
     if (m_currentType == "line") {
-        qApp->setOverrideCursor(setCursorShape(m_currentType, colorIndex(m_penColor)));
+        setCursorValue = BaseUtils::setCursorShape(m_currentType, BaseUtils::colorIndex(m_penColor));
     } else if (m_currentType == "arrow" && ConfigSettings::instance()->value("arrow", "is_straight").toBool()) {
-        qApp->setOverrideCursor(setCursorShape("straightLine"));
+        setCursorValue = BaseUtils::setCursorShape("straightLine");
     } else {
-        qApp->setOverrideCursor(setCursorShape(m_currentType));
+        setCursorValue = BaseUtils::setCursorShape(m_currentType);
+    }
+    // 避免相同的光标样式重复设置
+    if(*qApp->overrideCursor() != setCursorValue) {
+        qApp->changeOverrideCursor(setCursorValue);
     }
 }
 
