@@ -1,10 +1,12 @@
 #pragma once
 #include "widgets/ut_shapeswidget.h" //放前面
 #include "ut_main_window.h"
+#include "utils/ut_pixmergethread.h"
+#include "utils/ut_scrollScreenshot.h"
 #include "utils/ut_audioutils.h"
 #include "utils/ut_baseutils.h"
 #include "utils/ut_configsettings.h"
-#include "utils/ut_desktopinfo.h"
+//#include "utils/ut_desktopinfo.h"
 #include "utils/ut_screengrabber.h"
 #include "utils/ut_shortcut.h"
 #include "utils/ut_tempfile.h"
@@ -16,6 +18,7 @@
 #include "widgets/ut_zoomIndicator.h"
 #include "menucontroller/ut_menucontroller.h"
 #include "dbusinterface/ut_dbusnotify.h"
+#include "dbusinterface/ut_ocrinterface.h"
 #include "ut_RecorderRegionShow.h"
 #include "ut_countdown_tooltip.h"
 #include "ut_settings.h"
@@ -23,7 +26,9 @@
 #include "ut_utils.h"
 #include "ut_button_feedback.h"
 #include "ut_record_process.h"
-#include "ut_screenshot.h"
+//#include "ut_screenshot.h"
+#include "utils/ut_voiceVolumeWatcher.h"
+#include "utils/ut_WaylandScrollMonitor.h"
 //#include "widgets/ut_shapeswidget.h"
 #include "widgets/ut_toptips.h"
 #include "widgets/ut_camerawidget.h"
@@ -37,9 +42,14 @@
 #include "widgets/ut_hintfilterprivate.h"
 #include "widgets/ut_toolbutton.h"
 #include "widgets/ut_toolbarwidget.h"
-#include "widgets/ut_toolbar.h"
+//#include "widgets/ut_toolbar.h"
 #include "widgets/ut_sidebar.h"
 #include "widgets/ut_sidebarwidget.h"
-
-
+#include "widgets/ut_scrollshottip.h"
+#include "waylandrecord/ut_avinputstream.h"
+#include "waylandrecord/ut_avoutputstream.h"
+#include "waylandrecord/ut_recordadmin.h"
+#include "waylandrecord/ut_waylandintegration.h"
+#include "waylandrecord/ut_waylandintegration_p.h"
+#include "waylandrecord/ut_writeframethread.h"
 
