@@ -28,8 +28,11 @@ TEST_F(HoverShadowFilterTest, eventFilter)
     m_hoverShadowFilter->eventFilter(widget,enterLeave);
     QEvent *enterMove = new QEvent(QEvent::Move);
     m_hoverShadowFilter->eventFilter(widget,enterMove);
-    if(nullptr != widget)
-        widget->deleteLater();
+
+    delete widget;
+    delete enterEvent;
+    delete enterLeave;
+    delete enterMove;
 }
 
 
