@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="bo" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -7,6 +7,10 @@ or press the shortcut again to stop recording</source>
         <translation>སྡེར་མའི་མཚོན་རྟགས་ལ་གནོན་རྒྱུ།
 ཡང་ན་བརྙན་ཕབ་ཀྱི་མྱུར་མཐེབ་མནན་ནས་བརྙན་ཕབ་མཚམས་འཇོག་བྱ་རྒྱུ།</translation>
     </message>
+    <message>
+        <source>Do not rotate your screen during recording</source>
+        <translation>བརྙན་ལེན་བཞིན་ཡོད་པས་སྐོར་བ་མ་རྒྱག</translation>
+    </message>
 </context>
 <context>
     <name>MainToolWidget</name>
@@ -81,6 +85,18 @@ or press the shortcut again to stop recording</source>
         <source>Screenshot</source>
         <translation>བརྙན་བཤུས།</translation>
     </message>
+    <message>
+        <source>The screenshot has been saved in the album</source>
+        <translation>ཡིག་ཆ་བཅད་ནས་པར་དེབ་ནང་ཉར་བ།</translation>
+    </message>
+    <message>
+        <source>Screenshot failed.</source>
+        <translation>པར་དྲས་མ་ཐུབ།</translation>
+    </message>
+    <message>
+        <source>Scrollshot</source>
+        <translation>འགུལ་ནས་ཡོལ་པར་བླངས།</translation>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -123,6 +139,41 @@ or press the shortcut again to stop recording</source>
         <translation>བརྙན་བཤུས་བརྙན་ཕབ་སྐར་ཆ་%1རྗེས་སུ་འགོ་སློང་སྲིད།</translation>
     </message>
 </context>
+<context>
+    <name>ScrollShotTip</name>
+    <message>
+        <source>Get help.</source>
+        <translation>རོགས་རམ་འཚོལ་བ།</translation>
+    </message>
+    <message>
+        <source>Failed to take a continuous screenshot.</source>
+        <translation>མུ་མཐུད་ཡོལ་པར་རྒྱག་ཐབས་མེད།</translation>
+    </message>
+    <message>
+        <source>Reached the bottom of the scroll area</source>
+        <translation>འགུལ་ཁུལ་གྱི་མཇུག་ངོས་ལ་སླེབས།</translation>
+    </message>
+    <message>
+        <source>Reached the maximum length</source>
+        <translation>རིང་ཐུང་རིང་ཤོས་སླེབས་ཟིན།</translation>
+    </message>
+    <message>
+        <source>adjust the capture area</source>
+        <translation>འཛིན་བཟུང་ཁུལ་སྙོམས་སྒྲིག་བྱེད།</translation>
+    </message>
+    <message>
+        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
+        <translation>ཙི་གུའི་འགྲིལ་འཁོར་སྒྲིལ་བའམ་འཛིན་བཟུང་ཁུལ་ལ་གཅིག་རྡེབ་བྱེད།</translation>
+    </message>
+    <message>
+        <source>Slow down the scrolling speed</source>
+        <translation>འགྲིལ་འཁོར་སྒྲིལ་ཚད་དལ་རུ་གཏོང་དང་།</translation>
+    </message>
+    <message>
+        <source>Invalid area, click to </source>
+        <translation>ནུས་མེད་ཁུལ། __གནོན་རོགས།</translation>
+    </message>
+</context>
 <context>
     <name>ShapesWidget</name>
     <message>
@@ -140,10 +191,6 @@ or press the shortcut again to stop recording</source>
         <source>Exit/Save</source>
         <translation>ཕྱིར་འཐེན།/ཉར་བ།</translation>
     </message>
-    <message>
-        <source>Drawing</source>
-        <translation>རི་མོ་བྲི་བ།</translation>
-    </message>
     <message>
         <source>Size Adjustment</source>
         <translation>ཁུལ་ཁོངས་སྙོམས་སྒྲིག</translation>
@@ -272,6 +319,22 @@ or press the shortcut again to stop recording</source>
         <source>Mouse</source>
         <translation>ཕབ་བཟོའི་ཙི་གུ།</translation>
     </message>
+    <message>
+        <source>Tools</source>
+        <translation>ཡོ་བྱད།</translation>
+    </message>
+    <message>
+        <source>Extract text</source>
+        <translation>ཡི་གེ་ངོས་འཛིན།</translation>
+    </message>
+    <message>
+        <source>Scrollshot</source>
+        <translation>འགུལ་ནས་ཡོལ་པར་བླངས།</translation>
+    </message>
+    <message>
+        <source>Pin screenshots</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ShotToolWidget</name>
@@ -438,6 +501,18 @@ or press the shortcut again to stop recording</source>
         <source>Show Pointer</source>
         <translation>འོད་རྟགས་གསལ་བ།</translation>
     </message>
+    <message>
+        <source>Extract Text</source>
+        <translation>ཡི་གེ་ངོས་འཛིན།</translation>
+    </message>
+    <message>
+        <source>Scrollshot</source>
+        <translation>འགུལ་ནས་ཡོལ་པར་བླངས།</translation>
+    </message>
+    <message>
+        <source>Pin screenshots</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
@@ -449,8 +524,12 @@ or press the shortcut again to stop recording</source>
 <context>
     <name>Utils</name>
     <message>
-        <source>Recordings</source>
-        <translation>སྒྲ་ཕབ།</translation>
+        <source>Screen recording is not supported at present</source>
+        <translation>བརྙན་ཕབ་བྱེད་ནུས་གནས་སྐབས་སྤྱོད་མི་ཆོག</translation>
+    </message>
+    <message>
+        <source>Exit</source>
+        <translation>ཕྱིར་འཐེན།</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
